#ifndef debian_h
#define debian_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_debian: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_debian */
public:
	MODULE_debian (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_debian */
};

class USER;
class SHADOW;

#include "debian.p"

#endif
